nan_box_smooth_3d_phase

Function nan_box_smooth_3d_phase 

pub fn nan_box_smooth_3d_phase(
    phase: &[f64],
    sigma: [f64; 3],
    mask: &[u8],
    grid: &Grid,
) -> Vec<f64>
Masked phase smoothing via the complex representation, using nan_box_smooth_3dgaussiansmooth3d_phase(phase, sigma; mask) of MriResearchTools.jl. Returns NaN where the smoothed complex value is undefined (far outside the mask).