pub fn ensure_file(
model_id: &str,
file: &WeightFile,
) -> Result<PathBuf, DownloadError>Expand description
Ensure a single weight file is present locally, downloading it if needed, and
return its path. See ensure_file_with_progress.
pub fn ensure_file(
model_id: &str,
file: &WeightFile,
) -> Result<PathBuf, DownloadError>Ensure a single weight file is present locally, downloading it if needed, and
return its path. See ensure_file_with_progress.