pub fn ensure_model(spec: &ModelSpec) -> Result<Vec<PathBuf>, DownloadError>Expand description
Ensure every weight file for a model is present, returning their paths in
ModelSpec::files order.
pub fn ensure_model(spec: &ModelSpec) -> Result<Vec<PathBuf>, DownloadError>Ensure every weight file for a model is present, returning their paths in
ModelSpec::files order.