pub fn cache_path(file: &WeightFile) -> PathBufExpand description
The path a weight file would occupy in the cache (whether or not it exists).
pub fn cache_path(file: &WeightFile) -> PathBufThe path a weight file would occupy in the cache (whether or not it exists).